@@ -33,6 +33,7 @@
 from __future__ import annotations
 
 import functools
+import logging
 import os
 import socket
 import subprocess
@@ -50,6 +51,8 @@ from univention import uldap
 from univention.config_registry import ConfigRegistry
 
 
+logger = logging.getLogger('test')
+
 try:
     from univention.admin.uldap import access
 except ImportError:
@@ -659,6 +662,31 @@ def is_port_open(port: int, hosts: Iterable[str] | None = None, timeout: float =
     return False
 
 
+def no_change_in_file(no_change_for: int, log_file: str) -> bool:
+    modify_time = os.path.getmtime(log_file)
+    current_time = time.time()
+    if (current_time - modify_time) >= no_change_for:
+        return True
+    return False
+
+
+def wait_for_s4_connector_to_be_inactive(no_change_for: int = 15) -> None:
+    log_file = '/var/log/univention/connector-s4.log'
+    if not os.path.isfile(log_file):
+        return
+    for i in range(30):
+        if no_change_in_file(no_change_for, log_file):
+            logger.debug(f'no change in {log_file} for {no_change_for}s')
+            print(f'no change in {log_file} for {no_change_for}s')
+            break
+        logger.info('connector is active, waiting')
+        print('connector is active, waiting')
+        time.sleep(no_change_for + 3)
+    else:
+        print('wait_for_s4_connector_to_be_inactive timed out, contiuing anyway')
+        logger.error('wait_for_s4_connector_to_be_inactive timed out, contiuing anyway')
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
